#  Copyright (c) 2019 Jeorme Douay <jerome@far-out.biz>
#  MIT Liecnce, see the licence file for more information.

import mdfreader as mdfr
import pandas

class MDF(object):
    '''
    MDF class to handle MDF read operation
    '''

    def __init__(self):
        super().__init__()
        #self.mdf = mdfr.mdf()

    def Load(self, filename):
        '''
        Load the MDF file in memory
        :param filename: full path of the file anem to be opened
        :return: Nothing
        '''
        self.mdf = mdfr.Mdf(filename)

    def isChannel(self, name):
        '''
        check if the channel name supplied is in the MDF file
        :param name: name of the signal/channel
        :return: True if in file, otherwise False
        '''
        for time in self.mdf.masterChannelList:
            t = self.mdf.masterChannelList[time]
            if name in t:
                return True
        return False

    def Get(self, channel):
        '''
        Get the data designated by the channel name
        :param channel: channel name
        :return: pandas dataframe containing the data
        '''
        if (self.mdf.get_channel(channel)):
            data = pandas.DataFrame(self.mdf.get_channel_data(channel), index=self.mdf.get_channel_data(self.mdf.get_channel_master(channel)))
            data.columns = [channel]
            return data
        return pandas.DataFrame()
