#  Copyright (c) 2019 Jeorme Douay <jerome@far-out.biz>
#  MIT Liecnce, see the licence file for more information.

import pandas
from pyPowerTrain.mdf import MDF

class Measurement(object):
    '''
    Measurement class to handle mdf file and data retrieval
    '''

    def __init__(self):
        super().__init__()
        self.signals = pandas.DataFrame(columns=['signal', 'rename'])
        # self.signals = self.signals.append(pandas.DataFrame([['$PAUSE_COMMENT','pause']], columns=['signal', 'rename']))
        self.results = pandas.DataFrame()
        self.data = pandas.DataFrame()

    def ResetSignals(self):
        self.signals = pandas.DataFrame(columns=['signal', 'rename'])
        # self.signals = self.signals.append(pandas.DataFrame([['$PAUSE_COMMENT','pause']], columns=['signal', 'rename']))

    def SetSignals(self, signal, rename=''):
        '''
        Set a signal to be retrieved from the MDF. If a rename name is supplied, the signals will be reneamed.
        If more than one signal as the same rename name, all signals will be checked until one available is found.
        :param signal: signal name
        :param rename: name to be renamed to
        :return: None
        '''
        if (rename == ''):
            rename = signal
        for index, row in self.signals.iterrows():
            if (row['signal'] == signal):
                return
        self.signals = self.signals.append(pandas.DataFrame([[signal, rename]], columns=['signal', 'rename']))

    def Data(self,filename):
        '''
        Read the MDF file and retrieved the requested data
        :param filename: filename ( with full path ) of the MDF file to open
        :return: pandas dataframe contaiing the datas
        '''
        mdf=MDF()
        mdf.Load(filename)
        data = pandas.DataFrame()
        for n, d in self.signals.groupby('rename'):  # , sort=False):
            for index, row in d.iterrows():
                tmp = pandas.DataFrame()
                if (mdf.isChannel(row['signal']) == False):
                    continue
                tmp = mdf.Get(row['signal'])
                tmp.rename(columns={row['signal']: row['rename']}, inplace=True)
                break

            if (len(tmp.index) == 0):
                text = 'Channel : '
                for signal in d:
                    text = "%s %s" % (text, row['signal'])
                print("%s not present in file" % (text))
                return pandas.DataFrame()
            else:
                data = data.join(tmp, how='outer')

        # generate segments
        #        data['startseg'] = 0
        #        data['startseg'].iloc[0] = 1

        # check delta_t

        data = data.ffill()
        data = data.drop_duplicates()
        return data
