#  Copyright (c) 2019 Jeorme Douay <jerome@far-out.biz>
#  MIT Liecnce, see the licence file for more information.

import pandas

class Trigger(object):
    '''
    Generate Table at the time of the event. The event shall be generated from a digital signal
    '''

    def __init__(self):
        super().__init__()
        self.signals = []
        self.trigger = ""
        self.up=True # determine direction of trigger

    def Set(self, names):
        '''
        Set the name of the signal to be extracted at the time of the trigger event
        :param names: list of signals name
        :return: None
        '''
        self.signals = names

    def SetTrigger(self, name, up=True):
        '''
        Set the name of the trigger signal
        :param name: name of the signal to be used as trigger ( digital )
        :param up: True if the event is rising
        :return: None
        '''
        self.trigger = name
        self.up=up

    def Process(self, data,):
        '''
        Process the data and returns the events in a pandas dataframe
        :param data: data to be analysed
        :return: pandas dataframe with all the signals and events
        '''
        self.__Change(self.trigger, data)

        if (self.up == True):
            pre = data.loc[data["%s_mod" % (self.trigger)] > 0]
        else:
            pre = data.loc[data["%s_mod" % (self.trigger)] < 0]

        pre = pre[self.signals]
        pre = pre.dropna()
        pre['time_pre']=pre.index
        return (pre)

    def __Change(self, name, data):
        dest = "%s_mod" % (name)
        data[dest] = data[name].shift(-1) - data[name]
        data.dropna()
